# presence-stats
Discord presence stats show your pc stats<br>
yea i made this because i bored
## usage
install python (*of course*)<br>
open command prompt and do any of these commands
```bash
Script/activate
```
or
```
pip install -r requirements.txt
```
yea that's it then run program

### but i get this from pypi
then just do
```py
import presencestats

presencestats.launch()
```
that's it<br>
want cli?
```bash
presencestats
```
there.
=======

